@@ -8,9 +8,9 @@ from peek_plugin_gis_diagram._private.storage.DeclarativeBase import Declarative
 
 @addTupleType
 class StringIntTuple(Tuple, DeclarativeBase):
-    __tupleType__ = gisDiagramTuplePrefix + 'StringIntTuple'
-    __tablename__ = 'StringIntTuple'
+    __tupleType__ = gisDiagramTuplePrefix + "StringIntTuple"
+    __tablename__ = "StringIntTuple"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     string1 = Column(String(50))
-    int1 = Column(Integer)
\ No newline at end of file
+    int1 = Column(Integer)
