@@ -5,23 +5,20 @@
  */
 
 export abstract class GisDiagramPositionService {
-    constructor() {
-    
-    }
-    
+    constructor() {}
+
     /** Position By Key
      *
      * @param dispKey: The key equipment to position on.
      *
      */
-    abstract positionByKey(dispKey: string): void ;
-    
+    abstract positionByKey(dispKey: string): void;
+
     /** Can Position By Key
      *
      * @param dispKey: The key equipment to position on.
      * @returns A promise that fires wth true or false.
      *
      */
-    abstract canPositionByKey(dispKey: string): Promise<boolean> ;
-    
-}
\ No newline at end of file
+    abstract canPositionByKey(dispKey: string): Promise<boolean>;
+}
