@@ -1,13 +1,11 @@
-import { Injectable } from "@angular/core"
+import { Injectable } from "@angular/core";
 import {
+    DiagramToolbarService,
     DiagramToolButtonI,
-    DiagramToolbarService
-} from "@peek/peek_plugin_diagram/DiagramToolbarService"
-import { gisDiagramModelSetKey } from "./_private/PluginNames"
+} from "@peek/peek_plugin_diagram/DiagramToolbarService";
+import { gisDiagramModelSetKey } from "./_private/PluginNames";
 
-export {
-    DiagramToolButtonI
-} from "@peek/peek_plugin_diagram/DiagramToolbarService"
+export { DiagramToolButtonI } from "@peek/peek_plugin_diagram/DiagramToolbarService";
 
 /** Gis Diagram Toolbar Service
  *
@@ -20,10 +18,8 @@ export {
 
 @Injectable()
 export class GisDiagramToolbarService {
-    constructor(private diagramService: DiagramToolbarService) {
-    
-    }
-    
+    constructor(private diagramService: DiagramToolbarService) {}
+
     /** Add Tool Button
      *
      * Call this method to add new tool buttons to the diagrams tool bar.
@@ -32,8 +28,10 @@ export class GisDiagramToolbarService {
      * to the diagrams tool bar.
      */
     addToolButton(toolButton: DiagramToolButtonI) {
-        this.diagramService.addToolButton(gisDiagramModelSetKey, null, toolButton)
-        
+        this.diagramService.addToolButton(
+            gisDiagramModelSetKey,
+            null,
+            toolButton
+        );
     }
-    
 }
